@@ -248,6 +248,7 @@ class CentralUnitAPI:
             DeviceType.TimedPowerSwitch,
             DeviceType.Shutter,
             DeviceType.Thermostat,
+            DeviceType.TimedSwitch,
         ],
     ):
         await self.login_if_needed()
@@ -370,7 +371,7 @@ class CentralUnitAPI:
                         type=device_type,
                     )
 
-                # add timed switch scenario
+                # add timed switch
                 elif device_type == DeviceType.TimedSwitch:
                     self._devices_map[item[ApiAttribute.ID]] = SwitchBeeTimedSwitch(
                         id=item[ApiAttribute.ID],
